@@ -11,11 +11,13 @@ def fake_pastaporto_token_for_user(
     if staff:
         credentials.append(Credential.STAFF)
 
+    now = datetime.utcnow()
     return jwt.encode(
         {
             "userInfo": {"id": user["id"], "email": user["email"]},
             "credentials": credentials,
-            "exp": datetime.utcnow() + timedelta(minutes=1),
+            "exp": now + timedelta(minutes=1),
+            "iat": now,
             "iss": "gateway",
         },
         secret,
@@ -24,11 +26,13 @@ def fake_pastaporto_token_for_user(
 
 
 def fake_service_to_service_token(secret: str, *, issuer: str, audience: str):
+    now = datetime.utcnow()
     return jwt.encode(
         {
             "iss": issuer,
             "aud": audience,
-            "exp": datetime.utcnow() + timedelta(minutes=1),
+            "exp": now + timedelta(minutes=1),
+            "iat": now,
         },
         secret,
         algorithm="HS256",
